pub struct HotReloadArgs {
pub timestamp: DInstant,
pub propagation: EventPropagationHandle,
/* private fields */
}Expand description
Args for HOT_RELOAD_EVENT.
Fields
timestamp: DInstantInstant the event happened.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl HotReloadArgs
impl HotReloadArgs
Sourceimpl HotReloadArgs
impl HotReloadArgs
Sourcepub fn manifest_dir(&self) -> &Txt
pub fn manifest_dir(&self) -> &Txt
Crate directory that changed and caused the rebuild.